import re

from quicklogs import get_logger

logger = get_logger("fileflows")


file_extensions = [
    "3KO",
    "3dm",
    "3ds",
    "3dxml",
    "3g2",
    "3gp",
    "3mf",
    "7z",
    "CATPart",
    "CATProduct",
    "CGR",
    "GIF",
    "Gif",
    "JPEG",
    "JPG",
    "Jpeg",
    "Jpg",
    "PDF",
    "Pdf",
    "ZIP",
    "Zip",
    "a",
    "aac",
    "aaf",
    "aar",
    "action",
    "ada",
    "adb",
    "ads",
    "ai",
    "aiff",
    "ape",
    "apk",
    "ar",
    "asa",
    "asab",
    "asat",
    "asax",
    "asf",
    "ashx",
    "asm",
    "asmx",
    "asp",
    "aspx",
    "au",
    "avchd",
    "avi",
    "avif",
    "axd",
    "azw",
    "azw1",
    "azw3",
    "azw4",
    "azw6",
    "bak",
    "bas",
    "bash",
    "bat",
    "bin",
    "bmp",
    "br",
    "bz2",
    "c",
    "c++",
    "cab",
    "car",
    "cbl",
    "cbr",
    "cbz",
    "cc",
    "cfm",
    "cgi",
    "class",
    "classphp",
    "clj",
    "cob",
    "com",
    "command",
    "config",
    "cpio",
    "cpp",
    "crx",
    "cs",
    "csh",
    "csi",
    "css",
    "cssaspx",
    "csv",
    "cxx",
    "d",
    "dae",
    "dat",
    "dav",
    "db",
    "dds",
    "deb",
    "diff",
    "dll",
    "dmg",
    "do",
    "doc",
    "docx",
    "drc",
    "dwg",
    "dxf",
    "e",
    "ebook",
    "egg",
    "el",
    "eot",
    "eps",
    "epub",
    "exe",
    "f",
    "f3d",
    "f77",
    "f90",
    "feather",
    "fish",
    "flac",
    "flv",
    "for",
    "fth",
    "ftn",
    "gcode",
    "gif",
    "go",
    "gpx",
    "groovy",
    "gsm",
    "gz",
    "h",
    "h5",
    "hdf",
    "hdf5",
    "heic",
    "heif",
    "hh",
    "hpp",
    "hs",
    "htc",
    "htm",
    "html",
    "hxx",
    "iam",
    "ico",
    "ics",
    "iges",
    "igs",
    "inc",
    "include",
    "incphp",
    "ini",
    "ipt",
    "iso",
    "it",
    "iwb",
    "iwp",
    "jar",
    "java",
    "jpeg",
    "jpg",
    "js",
    "json",
    "jsp",
    "jsx",
    "jxl",
    "kml",
    "kmz",
    "ksh",
    "kt",
    "kts",
    "less",
    "lha",
    "lhs",
    "lisp",
    "log",
    "lua",
    "lz",
    "lz4",
    "lzma",
    "lzo",
    "m",
    "m2ts",
    "m2v",
    "m3u",
    "m4",
    "m4a",
    "m4p",
    "m4v",
    "mar",
    "max",
    "md",
    "mdb",
    "mid",
    "mkv",
    "mng",
    "mobi",
    "mod",
    "model",
    "mov",
    "mp2",
    "mp3",
    "mp4",
    "mpa",
    "mpe",
    "mpeg",
    "mpg",
    "mpv",
    "msg",
    "msi",
    "mts",
    "mxf",
    "mysqltxt",
    "new",
    "nim",
    "nsf",
    "nsv",
    "obj",
    "odp",
    "ods",
    "odt",
    "ogg",
    "ogm",
    "ogv",
    "ogx",
    "old",
    "org",
    "otf",
    "page",
    "pages",
    "pak",
    "par",
    "parquet",
    "patch",
    "pdf",
    "pea",
    "pgsqltxt",
    "php",
    "php3",
    "php4",
    "php5",
    "phtml",
    "pickle",
    "pkl",
    "pl",
    "pls",
    "ply",
    "png",
    "po",
    "pod",
    "pp",
    "ppt",
    "pptx",
    "prc",
    "prql",
    "prt",
    "ps",
    "ps1",
    "ps1xml",
    "psc1",
    "psd",
    "psd1",
    "psm",
    "psm1",
    "psrc",
    "pssc",
    "py",
    "qt",
    "r",
    "ra",
    "rar",
    "rb",
    "rm",
    "rmvb",
    "roq",
    "rpm",
    "rs",
    "rss",
    "rst",
    "rtf",
    "s",
    "s3m",
    "s7z",
    "sab",
    "sat",
    "scad",
    "scala",
    "scss",
    "sh",
    "shar",
    "shtml",
    "sid",
    "sldasm",
    "sldprt",
    "sms",
    "smt",
    "sql",
    "srt",
    "step",
    "stl",
    "stp",
    "svg",
    "svi",
    "swf",
    "swg",
    "swift",
    "tar",
    "tbz2",
    "tex",
    "tga",
    "tgz",
    "thm",
    "tif",
    "tiff",
    "tlz",
    "tpl",
    "ts",
    "tsv",
    "tsx",
    "ttf",
    "txt",
    "txz",
    "u3d",
    "v",
    "vb",
    "vcf",
    "vcxproj",
    "vda",
    "vob",
    "war",
    "wasm",
    "wav",
    "webm",
    "webp",
    "whl",
    "wll",
    "wma",
    "wmv",
    "woff",
    "woff2",
    "wpd",
    "wps",
    "wrl",
    "x_t",
    "xba",
    "xcf",
    "xcgm",
    "xcodeproj",
    "xhtml",
    "xll",
    "xls",
    "xlsx",
    "xm",
    "xml",
    "xmlgz",
    "xpi",
    "xsl",
    "xz",
    "yaml",
    "yml",
    "yuv",
    "zig",
    "zip",
    "zipx",
    "zsh",
    "zst",
]

file_extensions_re = re.compile(r"\.(" + "|".join(file_extensions) + r")$")
